from tkinter import Tk, Label, Entry, Button, Text, Scrollbar, END
from symspellpy import SymSpell, Verbosity

def correct_spellings():
    text = text_entry.get()
    
    # maximum edit distance per dictionary precalculation
    max_edit_distance_dictionary = 2
    prefix_length = 7
    # create object
    sym_spell = SymSpell(max_edit_distance_dictionary, prefix_length)
    # load dictionary
    dictionary_path = "frequency_dictionary_en_82_765.txt"
    term_index = 0  # column of the term in the dictionary text file
    count_index = 1  # column of the term frequency in the dictionary text file
    if not sym_spell.load_dictionary(dictionary_path, term_index, count_index):
        result_label.config(text="Dictionary file not found")
        return

    # max edit distance per lookup
    max_edit_distance_lookup = 2

    # lookup suggestions for multi-word input strings (supports compound splitting & merging)
    suggestions = sym_spell.lookup_compound(text, max_edit_distance_lookup)
    # display suggestion term, edit distance, and term frequency
    corrected_text = " ".join(suggestion.term for suggestion in suggestions)
    result_label.config(text=corrected_text)

    # Clear history if 'clear' is entered
    if text.lower() == 'clear':
        history_text.config(state='normal')
        history_text.delete('1.0', END)
        history_text.config(state='disabled')
    else:
        # Add to history
        history_text.config(state='normal')
        history_text.insert(END, text + '\n')
        history_text.config(state='disabled')

def exit_program():
    root.destroy()

root = Tk()
root.title("Spell Correction Program")

text_label = Label(root, text="Enter text:")
text_label.pack()

text_entry = Entry(root, width=30)
text_entry.pack()

correct_button = Button(root, text="Correct Spelling", command=correct_spellings)
correct_button.pack()

result_label = Label(root, text="")
result_label.pack()

history_label = Label(root, text="History:")
history_label.pack()

history_text = Text(root, height=10, width=30)
history_text.pack()

scrollbar = Scrollbar(root)
scrollbar.pack(side='right', fill='y')
history_text.config(yscrollcommand=scrollbar.set)
scrollbar.config(command=history_text.yview)

exit_button = Button(root, text="Exit", command=exit_program)
exit_button.pack()

root.mainloop()
